@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-14'; # DATE
+our $DATE = '2023-01-19'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.047'; # VERSION
+our $VERSION = '0.048'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl distribution name with version number suffix, e.g. Foo-Bar@0.001',
@@ -60,7 +60,7 @@ Sah::Schema::perl::distname_with_ver - Perl distribution name with version numbe
 
 =head1 VERSION
 
-This document describes version 0.047 of Sah::Schema::perl::distname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2023-01-14.
+This document describes version 0.048 of Sah::Schema::perl::distname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2023-01-19.
 
 =head1 SYNOPSIS
 
@@ -98,11 +98,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "Foo::Bar\@0.5_001";
+ $data = "Foo-Bar\@1.0.0";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "Foo-Bar";
+ $data = "";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -113,12 +113,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "Foo::Bar\@0.5_001";
- my $res = $validator->($data); # => ["","Foo-Bar\@0.5_001"]
+ $data = "Foo-Bar\@1.0.0";
+ my $res = $validator->($data); # => ["","Foo-Bar\@1.0.0"]
  
  # a sample invalid data
- $data = "Foo-Bar";
- my $res = $validator->($data); # => ["Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z","Foo-Bar"]
+ $data = "";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
