@@ -3,9 +3,9 @@ package Sah::Schema::perl::identifier::unqualified_ascii;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-14'; # DATE
+our $DATE = '2023-01-19'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.047'; # VERSION
+our $VERSION = '0.048'; # VERSION
 
 our $schema = [str => {
     summary => 'Unqualified identifier in Perl, without "use utf8" in effect',
@@ -47,7 +47,7 @@ Sah::Schema::perl::identifier::unqualified_ascii - Unqualified identifier in Per
 
 =head1 VERSION
 
-This document describes version 0.047 of Sah::Schema::perl::identifier::unqualified_ascii (from Perl distribution Sah-Schemas-Perl), released on 2023-01-14.
+This document describes version 0.048 of Sah::Schema::perl::identifier::unqualified_ascii (from Perl distribution Sah-Schemas-Perl), released on 2023-01-19.
 
 =head1 SYNOPSIS
 
@@ -91,7 +91,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "";
+ $data = "\$foo";
  my $errmsg = $validator->($data); # => "Must match regex pattern qr(\\A[A-Za-z_][A-Za-z_0-9]{0,250}\\z)"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -106,8 +106,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["","foo"]
  
  # a sample invalid data
- $data = "";
- my $res = $validator->($data); # => ["Must match regex pattern qr(\\A[A-Za-z_][A-Za-z_0-9]{0,250}\\z)",""]
+ $data = "\$foo";
+ my $res = $validator->($data); # => ["Must match regex pattern qr(\\A[A-Za-z_][A-Za-z_0-9]{0,250}\\z)","\$foo"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
