@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-14'; # DATE
+our $DATE = '2023-01-19'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.047'; # VERSION
+our $VERSION = '0.048'; # VERSION
 
 use Regexp::Pattern::Perl::Module ();
 
@@ -125,7 +125,7 @@ Sah::Schema::perl::modname_with_optional_args - Perl module name (e.g. Foo::Bar)
 
 =head1 VERSION
 
-This document describes version 0.047 of Sah::Schema::perl::modname_with_optional_args (from Perl distribution Sah-Schemas-Perl), released on 2023-01-14.
+This document describes version 0.048 of Sah::Schema::perl::modname_with_optional_args (from Perl distribution Sah-Schemas-Perl), released on 2023-01-19.
 
 =head1 SYNOPSIS
 
@@ -169,12 +169,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "Foo::Bar=arg1,arg2";
+ $data = "Foo::Bar";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
  $data = ["Foo",["arg1","arg2"],{}];
- my $errmsg = $validator->($data); # => "String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"Foo::Bar=arg1,arg2\") at (eval 3149) line 29.\n"
+ my $errmsg = $validator->($data); # => "String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"Foo::Bar\") at (eval 3149) line 29.\n"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -184,12 +184,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "Foo::Bar=arg1,arg2";
- my $res = $validator->($data); # => ["","Foo::Bar=arg1,arg2"]
+ $data = "Foo::Bar";
+ my $res = $validator->($data); # => ["","Foo::Bar"]
  
  # a sample invalid data
  $data = ["Foo",["arg1","arg2"],{}];
- my $res = $validator->($data); # => ["String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"Foo::Bar=arg1,arg2\") at (eval 3169) line 29.\n",["Foo",["arg1","arg2"],{}]]
+ my $res = $validator->($data); # => ["String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"Foo::Bar\") at (eval 3169) line 29.\n",["Foo",["arg1","arg2"],{}]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
